@@ -8,7 +8,7 @@ use std::collections::HashMap;
 use bio::stats::{bayesian::model::Likelihood, LogProb};
 
 use crate::utils::NUMERICAL_EPSILON;
-use crate::variants::evidence::observation::{IndelOperations, Observation, ReadPosition};
+use crate::variants::evidence::observation::{Observation, ReadPosition};
 use crate::variants::model::bias::Biases;
 use crate::variants::model::AlleleFreq;
 use crate::variants::sample::Pileup;
@@ -22,10 +22,7 @@ pub(crate) struct Event {
     pub(crate) biases: Biases,
 }
 
-fn prob_sample_alt(
-    observation: &Observation<ReadPosition, IndelOperations>,
-    allele_freq: LogProb,
-) -> LogProb {
+fn prob_sample_alt(observation: &Observation<ReadPosition>, allele_freq: LogProb) -> LogProb {
     if allele_freq != LogProb::ln_one() {
         // The effective sample probability for the alt allele is the allele frequency times
         // the probability to obtain a feasible fragment (prob_sample_alt).
@@ -89,7 +86,7 @@ impl ContaminatedSampleLikelihoodModel {
         allele_freq_secondary: LogProb,
         biases_primary: &Biases,
         biases_secondary: &Biases,
-        observation: &Observation<ReadPosition, IndelOperations>,
+        observation: &Observation<ReadPosition>,
     ) -> LogProb {
         // Step 1: likelihoods for the mapping case.
         // Case 1: read comes from primary sample and is correctly mapped
@@ -166,7 +163,7 @@ impl SampleLikelihoodModel {
         &self,
         allele_freq: LogProb,
         biases: &Biases,
-        observation: &Observation<ReadPosition, IndelOperations>,
+        observation: &Observation<ReadPosition>,
     ) -> LogProb {
         // Step 1: likelihood for the mapping case.
         let prob = likelihood_mapping(allele_freq, biases, observation);
@@ -191,7 +188,7 @@ impl SampleLikelihoodModel {
 fn likelihood_mapping(
     allele_freq: LogProb,
     biases: &Biases,
-    observation: &Observation<ReadPosition, IndelOperations>,
+    observation: &Observation<ReadPosition>,
 ) -> LogProb {
     // Step 1: calculate probability to sample from alt allele
     let prob_sample_alt = prob_sample_alt(observation, allele_freq);
@@ -229,12 +226,6 @@ impl Likelihood<SingleSampleCache> for SampleLikelihoodModel {
                 prob + lh
             });
 
-            // dbg!(pileup);
-            // panic!("test");
-            // if *events.secondary.allele_freq == 0.0 {
-            //     dbg!((events, likelihood));
-            // }
-
             assert!(!likelihood.is_nan());
 
             cache.insert(event.clone(), likelihood);
