@@ -106,13 +106,14 @@ where
 }
 
 #[derive(Debug, Clone, Hash, PartialEq, Eq)]
-struct VafLfc {
+pub(crate) struct VafLfc {
     sample_a: usize,
     sample_b: usize,
     predicate: Log2FoldChangePredicate,
 }
 
-#[derive(Debug, Default, Clone, Hash, PartialEq, Eq)]
+#[derive(Debug, Default, Clone, Hash, PartialEq, Eq, Getters)]
+#[getset(get = "pub(crate)")]
 pub(crate) struct LikelihoodOperands {
     events: VecMap<likelihood::Event>,
     lfcs: Vec<VafLfc>,
@@ -160,7 +161,7 @@ impl GenericPosterior {
     ) -> LogProb {
         let mut subdensity = |likelihood_operands: &mut LikelihoodOperands| {
             let p = if vaf_tree_node.is_leaf() {
-                joint_prob(&likelihood_operands, data)
+                joint_prob(likelihood_operands, data)
             } else if vaf_tree_node.is_branching() {
                 LogProb::ln_sum_exp(
                     &vaf_tree_node
